# Joking


Joking is a python library for getting random dad jokes and more kinds
of jokes

![image0](https://img.shields.io/badge/build-Passing-green?style=for-the-badge)
![forthebadge](https://forthebadge.com/images/badges/gluten-free.svg)
![forthebadge2](https://forthebadge.com/images/badges/powered-by-electricity.svg)
![image3](https://img.shields.io/badge/License-MIT-orange?style=for-the-badge)
![image4](https://bit.ly/3cTlr54)
![image5](https://tinyurl.com/badgesdhdh)
![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)
![image7](https://tinyurl.com/emails83) 
![PyPI - Downloads](https://tinyurl.com/smoler)

# Installation

you can install it by using the [pip](https://pip.pypa.io/en/stable/)
package manager

``` bash
pip install Joking
```

# How to Use


``` python
Multiple_Jokes(i) #i is for the amount of dad jokes
```

``` python
random_dad_joke() #prints out a random dad joke
```

``` python
programming_joke() #prints a random programming joke
```

``` python
random_joke() #prints a random joke
```

``` python
sjoke() #Gets a specific joke using the joke id from https://icanhazdadjoke.com/
```

```  python
search_for_joke() #prints the top result for the joke you searched
```

``` python
Random_knock_knock_joke() #gets a random knock knock joke
```

``` python
skkjoke() #Gets a specific knock knock joke using the joke id
```

``` python
DarkJoke() #Gets a dark joke that is potentially sexist or racist
```

``` python
Pun() #Gets a random pun
```

``` python
Submit_joke() #submits a joke
```

# F.A.Q.

Q. *Who make's The Jokes?*

A. **The whole of the internet**

Q. *Are some jokes Inappropriate?*

A. **No. Most Joke's with the exception of Dark Jokes are not Inappropriate**

# How it works

It works by web scraping https://icanhazdadjoke.com/, jokes4us.com and using version
2 of jokeapi.dev 

# Joke id's

Joke ids are Joke ids from icanhazdadjoke.com or from
http://www.jokes4us.com/knockknockjokes/random/knockknock{id go here}.html To find
a jokes id just search icanhazdadjoke.com or find the knock knock joke
you want from
http://www.jokes4us.com/knockknockjokes/index.html

# How to contribute


- Start by going to https://github.com/Iwertyuiop123653/Joker
- Then fork the repository
- make the changes you want
- Then commit